@@ -7,7 +7,7 @@ use AnyEvent::RabbitMQ;
 use Data::Dumper;
 use Carp qw(longmess);
 
-our $VERSION = "3.1.2";
+our $VERSION = "3.1.3";
 
 sub connect {
     my %connection_opts = @_;
@@ -49,7 +49,7 @@ sub _open_channel_given_condvar {
 
 sub _report_error {
     my ($cv, $why) = @_;
-    if (ref($why)) {
+    if (ref($why) && $why->can('method_frame')) {
         my $method_frame = $why->method_frame;
         $cv->croak(longmess(
             sprintf '%s: %s',
@@ -115,9 +115,9 @@ AnyEvent::RabbitMQ::PubSub - Publish and consume RabbitMQ messages.
     $consumer->consume(
         $cv,
         sub {
-            my ($self, $msg) = @_;
+            my ($consumer, $msg) = @_;
             print 'received ', $msg->{body}->payload, "\n";
-            $self->channel->ack();
+            $consumer->ack($msg);
             $cv->send();
         },
     );
